Struct polkadot_core_primitives::InboundDownwardMessage [−][src]
pub struct InboundDownwardMessage<BlockNumber = BlockNumber> {
pub sent_at: BlockNumber,
pub msg: DownwardMessage,
}Expand description
A wrapped version of DownwardMessage. The difference is that it has attached the block number when
the message was sent.
Fields
sent_at: BlockNumberThe block number at which these messages were put into the downward message queue.
msg: DownwardMessageThe actual downward message to processes.